@@ -9,6 +9,9 @@
         my_build_block_content_op(aTHX_ orig_content_op)
 static OP* my_build_block_content_op(pTHX_ OP* orig_content_op);
 
+#define call_sub_op(name, args_op)  my_call_sub_op(aTHX_ name, args_op)
+static OP* my_call_sub_op(pTHX_ char *, OP*);
+
 #define build_catch_args_optree(block_op, class_name_sv) \
         my_build_catch_args_optree(aTHX_ block_op, class_name_sv)
 static OP* my_build_catch_args_optree(pTHX_ OP* block_op, SV* class_name_sv);
